/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include "FS.h"

volatile uint8 Reg[16] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
volatile uint16 Baud[15] = {20000,5000,2500,1250,625,312,156,104,52,26,625,625,625,625,625};
volatile uint16 SPIBitRate[7] = {480,240,120,48,24,12,5};
volatile uint8 DataIn;
volatile uint8 Addr = 16;

void DMA_init(volatile uint8*, volatile uint8*, volatile uint8*);
void shutDown();
void startUp();
void psocChanges();
void extChanges();

uint8 UART_1_Send;
uint8 SPIM_1_Shift;
uint8 ADC_INTR;
uint8 ADC_INTR_EN;
char sdFile[13];
char sdVolName[10];
uint8 sdNameCounter;
FS_FILE * pFile;
volatile uint8 SDMode;

CY_ISR ( ResetISRAddr )
{
    memset((void*)Reg, 0, sizeof(Reg));
    shutDown();
    startUp();
}

int main(void)
{
    CyGlobalIntEnable; /* Enable global interrupts. */
   
    DMA_init(Reg, &Addr, &DataIn);
   
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */
    ResetISR_StartEx( ResetISRAddr );
   
    startUp();
    
    for(;;)
    {
        /* Place your application code here. */
        psocChanges();
        if(Addr != 16)
        {
            extChanges();
        }
    }
}

void shutDown()
{
    // UART_1 ShutDown
    UART_1_Stop();
    UART_1_Clock_Stop();
    
    // SPIM_1 ShutDown
    SPIM_1_Stop();
    SPIM_1_Clock_Stop();   
    
    // ADC_SAR_1 ShutDown
    ADC_SAR_1_Stop();
    // SD Card ShutDown
    FS_DeInit();
    memset(sdFile, 0, sizeof(sdFile));
}

void startUp()
{   
    // 8000 Communication Startup
    INTR_Write(1);
    
    // Reset UART_1 variables
    UART_1_ReadTxStatus();
    UART_1_ClearRxBuffer();
    UART_1_Send = 1; 
    
    // Reset SPIM_1 variables
    SPIM_1_Shift = 1;
    SPIM_1_ReadTxStatus();
    
    // ADC_SAR_1 StartUp
    ADC_SAR_1_Start();
    ADC_SAR_1_IsEndConversion(ADC_SAR_1_RETURN_STATUS);
    ADC_INTR = 0;
    ADC_INTR_EN = 0;
    // SD Card Startup
    FS_Init();
    SDMode = 0;
}

void extChanges()
{
    Reg[Addr] = DataIn;
    switch(Addr & 0x0F)
    {
        case 0:
            if((Reg[0] & 0x0F) != 0)                                 // Turn UART_1 On
            {
                UART_1_Clock_Start();
                UART_1_Clock_SetDividerValue(Baud[(Reg[0] & 0x0F) - 1]);
                       
                UART_1_Send = 0;

                UART_1_Start();
            }
            else                                                     // Turn UART_1 Off
            {
                UART_1_Stop();
                       
                UART_1_Send = 1;
                                  
                UART_1_Clock_Stop();
            }
            break;
        case 1:
            if(UART_1_Send == 0)                                     // Send a byte through UART_1
            {
                UART_1_Send = 1;
                UART_1_PutChar(Reg[1]);
            }
            break;
        case 2:
            break;
        case 3:
            if((Reg[3] & 0x07) != 0)                                 // Turn SPIM_1 On
            {
                SPIM_1_Clock_Start();
                SPIM_1_Clock_SetDividerValue(SPIBitRate[(Reg[3] & 0x07) - 1]);
                       
                SPIM_1_Shift = 0;

                SPIM_1_Start();
            }
            else                                                     // Turn SPIM_1 Off
            {
                SPIM_1_Stop();
                       
                SPIM_1_Shift = 1;
                                  
                SPIM_1_Clock_Stop();
            }
            break;
        case 4:
            if(SPIM_1_Shift == 0)                                    // Send a byte through SPIM_1
            {
                SPIM_1_Shift = 1;
                SPIM_1_WriteTxData(Reg[4]);
            }
            break;
        case 5:
            
            break;
        case 6:
            break;
        case 7:
            break;
        case 8:
            break;
        case 9:
            break;
        case 10:
            break;
        case 11:
            break;
        case 12:
            break;
        case 13:                                                     // This register is the control register for the SD EmFile Interface
            if((Reg[13] & 0x0F) == 0){break;}
            else if((Reg[13] & 0x0F) == 1){memset(sdFile, 0, sizeof(sdFile)); sdNameCounter = 12; SDMode = 1;}
            else if((Reg[13] & 0x0F) == 2){pFile = FS_FOpen(sdFile, "w"); SDMode = 2;}
            else if((Reg[13] & 0x0F) == 3){pFile = FS_FOpen(sdFile, "r"); SDMode = 3;}
            else if((Reg[13] & 0x0F) == 4){FS_FClose(pFile); SDMode = 0;}

            Reg[13] = Reg[13] | 0x40;
            break;
        case 14:                                                     // This register is the data communication register for the SD EmFile Interface
            if(SDMode == 1){if(sdNameCounter != 0){sdFile[12 - sdNameCounter] = Reg[14]; sdNameCounter--;}}
            else if(SDMode == 2){FS_Write(pFile, (void*)(Reg + 14), 1u);}
            else if(SDMode == 3){FS_Read(pFile, (void*)(Reg + 14), 1u);}

            Reg[13] = Reg[13] | 0x40;
            break;
        case 15:
            if(Reg[15] == 00) {ADC_INTR = 0;}                        // This register handles the Analog to Digital converter
            else if(Reg[15] == 1) {ADC_INTR = 0; ADC_INTR_EN = 1; ADC_SAR_1_StartConvert();}
            else {ADC_INTR = 0; ADC_SAR_1_StartConvert();}
            break;
    }
    Addr = 16;
}

void psocChanges()
{
    // UART_1 Changes
    if(UART_1_GetRxBufferSize() == 1)                                // This code runs if UART_1 received a byte
    {
        Reg[2] = UART_1_ReadRxData();
        Reg[0] = Reg[0] | 0x40;
    }
    if(UART_1_ReadTxStatus() & UART_1_TX_STS_COMPLETE)               // This code runs if UART_1 finishes transmitting a byte
    {
        Reg[0] = Reg[0] | 0x80;
       
        UART_1_Send = 0;
    }
    
    // SPIM_1 Changes
    if(SPIM_1_ReadTxStatus() & SPIM_1_STS_BYTE_COMPLETE)             // This code runs if SPIM_1 finishes shifting a byte
    {
        Reg[3] = Reg[3] | 0x80;
        Reg[4] = SPIM_1_ReadRxData();
        SPIM_1_Shift = 0;
    }
    // ADC Changes
    if(ADC_SAR_1_IsEndConversion(ADC_SAR_1_RETURN_STATUS))
    {
        Reg[15] = ADC_SAR_1_GetResult8();
        if(ADC_INTR_EN == 1){ADC_INTR = 1;}
        ADC_INTR_EN = 0;
    }
                                                                     // Handle the interrupt line to the 8051 
    if(((Reg[0] & 0xA0) == 0xA0) | ((Reg[0] & 0x50) == 0x50) | ((Reg[3] & 0xC0) == 0xC0) | (ADC_INTR == 1) | ((Reg[13] & 0xC0) == 0xC0)) {INTR_Write(0);}
    else {INTR_Write(1);}
}
/* [] END OF FILE */